| ComDim-classes | R Documentation |
Object of the type MultiBlock, to use as input for ComDim
analyses.
The output of a ComDim analysis.
Samplesvector with the sample names. If this data is not available, the slot will be filled with integers.
DataA list with the data-blocks.
VariablesA character vector with the variable names. If this data is not available, the slot will be filled with integers.
BatchA list with the vectors with the batch information for each data-block. Facultative.
MetadataA list with the samples metadata.
MethodThe algorithm used in the core of the ComDim analysis (ex. PCA, PLS,...)
ndimThe number of components.
Q.scoresThe Global scores.
T.scoresThe Local scores.
P.loadingsThe Loadings
SaliencesThe Saliences
R2XThe explained variance of the MultiBlock.
R2YFor regression or discriminant models, the explained variance of the Y-block.
Q2For regression or discriminant models, the predicted variance of the Y-block.
DQ2For discriminant models, the predicted discriminant variance of the Y-block.
SingularThe singular values.
MeanThe mean values for each variable in the MultiBlock.
NormThe norm values for each variable in the MultiBlock.
PLS.modelFor ComDim analyses using PLS as core algorithm, it contains the W, B, B0 and Y).
cvFor ComDim_KOPLS, it contains the index of the samples used during the cross-validation.
PredictionA list with the predicted Y, the decision rule used for sample classification, the sensitivity, the specificity, and a confusion matrix.
Metadatavector with the sample names. If this data is not available, the slot will be filled with integers.
variable.blockA vector with the same length than the P.loadings indicating the block each variable belongs to.
runtimeThe used running time.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.