R.ComDim-package: R.ComDim: ComDim Analysis in R

R.ComDim-packageR Documentation

R.ComDim: ComDim Analysis in R

Description

Provides functions to run ComDim analysis. ComDim is an unsupervised multi-block method that simultaneously considers multiple data tables to find latent components common to all tables as well as those specific to each table.

Author(s)

Maintainer: Francesc Puig-CastellvĂ­ puig.francesc@gmail.com


R.ComDim documentation built on May 13, 2026, 9:07 a.m.