| R.ComDim-package | R Documentation |
Provides functions to run ComDim analysis. ComDim is an unsupervised multi-block method that simultaneously considers multiple data tables to find latent components common to all tables as well as those specific to each table.
Maintainer: Francesc Puig-CastellvĂ puig.francesc@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.