| nrow,MultiBlock-method | R Documentation |
Return the number of rows (samples) in each block of a MultiBlock. For a valid MultiBlock all blocks share the same number of rows, so the result is a named integer vector with one (identical) value per block.
## S4 method for signature 'MultiBlock'
nrow(x)
x |
A MultiBlock object. |
A named integer vector with the number of rows per block.
b1 <- matrix(rnorm(500), 10, 50)
b2 <- matrix(rnorm(800), 10, 80)
mb <- MultiBlock(Data = list(b1 = b1, b2 = b2))
nrow(mb) # c(b1 = 10, b2 = 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.